@@ -117,14 +117,6 @@ class EchoHandler(object):
         echo_reply.data = msg.data
         datapath.send_msg(echo_reply)
 
-    @staticmethod
-    @set_ev_cls(ofp_event.EventOFPEchoReply)
-    def echo_reply_handler(ev):
-        # do nothing
-        # msg = ev.msg
-        # LOG.debug('echo reply ev %s %s', msg, str(msg.data))
-        pass
-
 
 @register_cls([HANDSHAKE_DISPATCHER, CONFIG_DISPATCHER, MAIN_DISPATCHER])
 class ErrorMsgHandler(object):
@@ -188,34 +180,13 @@ class ConfigHandler(object):
         set_config = ofproto_parser.OFPSetConfig(
             datapath, ofproto.OFPC_FRAG_NORMAL,
             128  # TODO:XXX
-            )
+        )
         datapath.send_msg(set_config)
 
         LOG.debug('move onto main mode')
         ev.msg.datapath.ev_q.set_dispatcher(MAIN_DISPATCHER)
 
-    # The above OFPC_DELETE request may trigger flow removed ofp_event.
-    # Just ignore them.
-    @staticmethod
-    @set_ev_cls(ofp_event.EventOFPFlowRemoved)
-    def flow_removed_handler(ev):
-        LOG.debug("flow removed ev %s msg %s", ev, ev.msg)
-
-    @staticmethod
-    @set_ev_cls(ofp_event.EventOFPBarrierReply)
-    def barrier_reply_handler(ev):
-        LOG.debug('barrier reply ev %s msg %s', ev, ev.msg)
-
 
 @register_cls(MAIN_DISPATCHER)
 class MainHandler(object):
-    @staticmethod
-    @set_ev_cls(ofp_event.EventOFPFlowRemoved)
-    def flow_removed_handler(ev):
-        pass
-
-    @staticmethod
-    @set_ev_cls(ofp_event.EventOFPPortStatus)
-    def port_status_handler(ev):
-        msg = ev.msg
-        LOG.debug('port status %s', msg.reason)
+    pass
