@@ -1,4 +1,4 @@
-# Copyright (C) 2011 Nippon Telegraph and Telephone Corporation.
+# Copyright (C) 2011, 2012 Nippon Telegraph and Telephone Corporation.
 # Copyright (C) 2011 Isaku Yamahata <yamahata at valinux co jp>
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -19,15 +19,15 @@ import struct
 
 from ryu import exception
 
-from . import ofproto
+from . import ofproto_common
 
 LOG = logging.getLogger('ryu.ofproto.ofproto_parser')
 
 
 def header(buf):
-    assert len(buf) >= ofproto.OFP_HEADER_SIZE
+    assert len(buf) >= ofproto_common.OFP_HEADER_SIZE
     #LOG.debug('len %d bufsize %d', len(buf), ofproto.OFP_HEADER_SIZE)
-    return struct.unpack_from(ofproto.OFP_HEADER_PACK_STR, buffer(buf))
+    return struct.unpack_from(ofproto_common.OFP_HEADER_PACK_STR, buffer(buf))
 
 
 _MSG_PARSERS = {}
